@@ -3,9 +3,9 @@ package middlewares
 import (
 	"github.com/sirupsen/logrus"
 
-	"github.com/cloudskiff/driftctl/pkg/alerter"
-	"github.com/cloudskiff/driftctl/pkg/resource"
-	"github.com/cloudskiff/driftctl/pkg/resource/aws"
+	"github.com/snyk/driftctl/pkg/alerter"
+	"github.com/snyk/driftctl/pkg/resource"
+	"github.com/snyk/driftctl/pkg/resource/aws"
 )
 
 // Explodes routes found in aws_default_route_table.route and aws_route_table.route to dedicated resources
