@@ -112,6 +112,8 @@ func TestAWS_Metadata_Flags(t *testing.T) {
 		AwsLoadBalancerResourceType:                    {},
 		AwsApplicationLoadBalancerResourceType:         {},
 		AwsClassicLoadBalancerResourceType:             {},
+		AwsLoadBalancerListenerResourceType:            {},
+		AwsApplicationLoadBalancerListenerResourceType: {},
 	}
 
 	schemaRepository := testresource.InitFakeSchemaRepository(tf.AWS, "3.19.0")
